@@ -19,6 +19,9 @@ def splitres(file_path, result_dir):
     Returns:
         return_val (list): list of result which will be written to a file.(need it for testing)
     """
+    file_path = str(file_path)
+    result_dir = str(result_dir)
+
     if os.path.isdir(file_path):
         return_val = []
         for root, _pre_dir, files in os.walk(file_path):
@@ -94,7 +97,7 @@ def parser_for_messtatfile(file_name):
         with open(file_name, 'r') as file:
             for line in file.read().split('\n'):
                 if 'package' in line:
-                    num = float(re.findall(r'\d+,\d+', line.split(' ')[1])[0].replace(",", "."))
+                    num = float(re.findall(r'\d+[,.]\d+', line.split(' ')[1])[0].replace(",", "."))
                     data.append(num)
     except PermissionError as ex:
         data = str(ex)
